/**
 * @(#) MBeanNames.java
 *
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2005 Fossil E-Commerce, http://www.fossilec.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: MBeanNames.java 69 2006-01-17 16:00:26Z rmarins $
 * -------------------------------------------------------------------------
 */

//
// This source code implements specifications defined by the Java
// Community Process. In order to remain compliant with the specification
// DO NOT add / change / or delete method signatures!
//

package javax.jbi.management;

/**
 * This interface provides methods to create JMX object names for component-
 * supplied MBeans. This ensures that component-supplied MBeans follow the JBI
 * implementation-determined naming convention.
 * <p>
 * Components obtain instances of this name creator using
 * {@link javax.jbi.component.ComponentContext#getMBeanNames()}.
 *
 * @author JSR208 Expert Group
 */
public interface MBeanNames {

    /**
	 * The custom name that must be used for bootstrap extensions
	 */
	public static final java.lang.String BOOTSTRAP_EXTENSION =
        "BootstrapExtension";

	/**
	 * The custom name that must be used for component life cycle extensions
	 */
	public static final java.lang.String COMPONENT_LIFE_CYCLE_EXTENSION =
        "LifeCycleExtension";

	/**
     * Formulate and return an MBean ObjectName for a custom control of this
     * name creator's JBI component.
     * <p>
     * This is used by components to create JMX names for their own JMX
     * controls, allowing the JBI implementation to prefix the created name to
     * fit within the implementation's own naming scheme.
     * <p>
     * Standard extensions must use the following custom name constants:
     * <ul>
     *   <li>Bootstrap (installer) extension: {@link 
     *   MBeanNames#BOOTSTRAP_EXTENSION}.</li>
     *   <li>Component life cycle extension: {@link
     *   MBeanNames#COMPONENT_LIFE_CYCLE_EXTENSION}.</li>
     * </ul>
     * <p>
     * All other custom component MBeans must use custom names that do not
     * collide with the standard extension names.
     * 
     * @param customName
     *            the name of the custom control; must be non-null and
     *            non-empty; must be legal for use in a JMX object name
     * @return the JMX ObjectName of the MBean, or <code>null</code> if the
     *         <code>customName</code> is invalid
     */
	public javax.management.ObjectName createCustomComponentMBeanName(
            java.lang.String customName);

	/**
	 * Retrieve the default JMX Domain Name for MBeans registered in this
	 * instance of the JBI implementation.
	 * 
	 * @return the JMX domain name for this instance of the JBI implemention;
	 *         must be non-null and non-empty
	 */
	public java.lang.String getJmxDomainName();
}
